summaryrefslogtreecommitdiffstats
path: root/src/app/treeview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/app/treeview.cpp')
-rw-r--r--src/app/treeview.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/app/treeview.cpp b/src/app/treeview.cpp
index a8c7b59..3ee9e4a 100644
--- a/src/app/treeview.cpp
+++ b/src/app/treeview.cpp
@@ -55,10 +55,10 @@ struct TreeView::Private {
KFileTreeViewItem* mDropTarget;
TQTimer* mAutoOpenTimer;
- KFileTreeViewItem* findViewItem(KFileTreeViewItem* tqparent,const TQString& text) {
+ KFileTreeViewItem* findViewItem(KFileTreeViewItem* parent,const TQString& text) {
TQListViewItem* item;
- for (item=tqparent->firstChild();item;item=item->nextSibling()) {
+ for (item=parent->firstChild();item;item=item->nextSibling()) {
if (item->text(0)==text) {
return static_cast<KFileTreeViewItem*>(item);
}
@@ -114,8 +114,8 @@ struct TreeView::Private {
};
-TreeView::TreeView(TQWidget* tqparent)
-: KFileTreeView(tqparent) {
+TreeView::TreeView(TQWidget* parent)
+: KFileTreeView(parent) {
d=new Private;
d->mView=this;
d->mBranch=0;
@@ -180,7 +180,7 @@ void TreeView::slotTreeViewPopulateFinished(KFileTreeViewItem* item) {
return;
}
// This URL is not a tqparent of a wanted URL, get out
if (!url.isParentOf(m_nextUrlToSelect)) return;
// Find the next child item and open it
@@ -180,7 +180,7 @@ void TreeView::slotTreeViewPopulateFinished(KFileTreeViewItem* item) {
return;
}
- // This URL is not a tqparent of a wanted URL, get out
+ // This URL is not a parent of a wanted URL, get out
if (!url.isParentOf(m_nextUrlToSelect)) return;
// Find the next child item and open it